@@ -74,7 +74,7 @@ def run_server(domain, port, workers):
         host="0.0.0.0",
         port=port,
         workers=workers,
-        backlog=int(os.environ.get(ENV_SANIC_BACKLOG, "100")),
+        backlog=ENV_SANIC_BACKLOG,
     )
 
 
