@@ -35,9 +35,9 @@ def from_endpoint_config(
 
         return FileProducer.from_endpoint_config(broker_config)
     elif broker_config.type == "kafka":
-        from rasa.core.brokers.kafka import KafkaProducer
+        from rasa.core.brokers.aiokafka import AIOKafkaMiddleware
 
-        return KafkaProducer.from_endpoint_config(broker_config)
+        return AIOKafkaMiddleware.from_endpoint_config(broker_config)
     else:
         return load_event_channel_from_module_string(broker_config)
 
