@@ -11,6 +11,7 @@ from fbmessenger.quick_replies import QuickReplies, QuickReply
 from sanic import Blueprint, response
 from sanic.request import Request
 from typing import Text, List, Dict, Any, Callable, Awaitable, Iterable, Optional
+from rasa.constants import ENV_IDENTITY_PROVIDER_HOST, ENV_IDENTITY_PROVIDER_PORT
 
 from rasa.core.channels.channel import UserMessage, OutputChannel, InputChannel
 from os import environ
@@ -140,8 +141,8 @@ class Messenger:
 
     async def startTracking(self, channelUserId, channel, sid):
         # make IDP request here and append guid to message
-        host = environ["IDENTITY_PROVIDER_HOST"]
-        port = environ["IDENTITY_PROVIDER_PORT"]
+        host = ENV_IDENTITY_PROVIDER_HOST
+        port = ENV_IDENTITY_PROVIDER_PORT
 
         headers = {"Conversation-Id": sid}
         params = {
