@@ -114,7 +114,7 @@ class MessageProcessor:
 
         if not self.policy_ensemble or not self.domain:
             # save tracker state to continue conversation from this state
-            self._save_tracker(tracker)
+            await self._save_tracker(tracker)
             warnings.warn(
                 "No policy ensemble or domain set. Skipping action prediction "
                 "and execution."
@@ -126,7 +126,7 @@ class MessageProcessor:
         duration = time.perf_counter() - start
         ACTION_PREDICT_EXECUTE_TIME.observe(duration)
         # save tracker state to continue conversation from this state
-        self._save_tracker(tracker)
+        await self._save_tracker(tracker)
 
         if isinstance(message.output_channel, CollectingOutputChannel):
             return message.output_channel.messages
@@ -137,7 +137,7 @@ class MessageProcessor:
 
         # we have a Tracker instance for each user
         # which maintains conversation state
-        tracker = self._get_tracker(sender_id)
+        tracker = await self._get_tracker(sender_id)
         if not tracker:
             logger.warning(
                 f"Failed to retrieve or create tracker for sender '{sender_id}'."
@@ -153,7 +153,7 @@ class MessageProcessor:
 
         probabilities, policy = self._get_next_action_probabilities(tracker)
         # save tracker state to continue conversation from this state
-        self._save_tracker(tracker)
+        await self._save_tracker(tracker)
         scores = [
             {"action": a, "score": p}
             for a, p in zip(self.domain.action_names, probabilities)
@@ -180,13 +180,13 @@ class MessageProcessor:
             message.text = self.message_preprocessor(message.text)
         # we have a Tracker instance for each user
         # which maintains conversation state
-        tracker = self._get_tracker(message.sender_id)
+        tracker = await self._get_tracker(message.sender_id)
         if tracker:
             await self._handle_message_with_tracker(message, tracker)
 
             if should_save_tracker:
                 # save tracker state to continue conversation from this state
-                self._save_tracker(tracker)
+                await self._save_tracker(tracker)
         else:
             logger.warning(
                 "Failed to retrieve or create tracker for sender "
@@ -206,7 +206,7 @@ class MessageProcessor:
 
         # we have a Tracker instance for each user
         # which maintains conversation state
-        tracker = self._get_tracker(sender_id)
+        tracker = await self._get_tracker(sender_id)
         if tracker:
             action = self._get_action(action_name)
             await self._run_action(
@@ -214,7 +214,7 @@ class MessageProcessor:
             )
 
             # save tracker state to continue conversation from this state
-            self._save_tracker(tracker)
+            await self._save_tracker(tracker)
         else:
             logger.warning(
                 f"Failed to retrieve or create tracker for sender '{sender_id}'."
@@ -279,7 +279,7 @@ class MessageProcessor:
     ) -> None:
         """Handle a reminder that is triggered asynchronously."""
 
-        tracker = self._get_tracker(sender_id)
+        tracker = await self._get_tracker(sender_id)
 
         if not tracker:
             logger.warning(
@@ -310,7 +310,7 @@ class MessageProcessor:
                 user_msg = UserMessage(None, output_channel, sender_id)
                 await self._predict_and_execute_next_action(user_msg, tracker)
             # save tracker state to continue conversation from this state
-            self._save_tracker(tracker)
+            await self._save_tracker(tracker)
 
     @staticmethod
     def _log_slots(tracker):
@@ -710,44 +710,45 @@ class MessageProcessor:
                 }
                 logger.info('[{}] - APP NAV: {}'.format(sender_id, app_nav))
                 asyncio.create_task(self.send_app_nav_async(sender_id, app_nav))
-                APP_NAV.labels(message._metadata['template_name'], 'disconnect').inc()
+                APP_NAV.labels(message._metadata['template_name'], 'disconnect', None).inc()
 
             elif message._metadata and message._metadata.get('message_type', None) == 'SPOKEN':
+                transcriber = message._metadata.get('transcriber', 'NA')
                 if message.metadata.get('reporting_error_type', None):
                     app_nav = {
-                    'key': '{}_nlu_{}'.format(message._metadata['template_name'], message._metadata['reporting_error_type']),
+                    'key': '{}_{}_nlu_{}'.format(transcriber, message._metadata['template_name'], message._metadata['reporting_error_type']),
                     'value': 'NO_INTENT'
                     }
                     logger.info('[{}] - APP NAV: {}'.format(sender_id, app_nav))
                     asyncio.create_task(self.send_app_nav_async(sender_id,app_nav))
-                    APP_NAV.labels(message._metadata['template_name'], message._metadata['reporting_error_type']).inc()
+                    APP_NAV.labels(message._metadata['template_name'], message._metadata['reporting_error_type'], transcriber ).inc()
                     
                 elif message.missed_intent and message.intent['confidence'] < message._metadata['nlu_threshold']:
                     app_nav = {
-                    'key': '{}_nlu_no_match'.format(message._metadata['template_name']),
+                    'key': '{}_{}_nlu_no_match'.format(transcriber, message._metadata['template_name']),
                     'value': 'NO_INTENT'
                     }
                     logger.info('[{}] - APP NAV: {}'.format(sender_id, app_nav))
                     asyncio.create_task(self.send_app_nav_async(sender_id,app_nav))
-                    APP_NAV.labels(message._metadata['template_name'], 'no_match').inc()
+                    APP_NAV.labels(message._metadata['template_name'], 'no_match', transcriber ).inc()
                     
                 elif message.intent and message.intent['name'] == USER_INTENT_OUT_OF_SCOPE:
                     app_nav = {
-                        'key': '{}_nlu_no_match'.format(message._metadata['template_name'] ),
+                        'key': '{}_{}_nlu_no_match'.format(transcriber, message._metadata['template_name'] ),
                         'value': 'NO_INTENT'
                     }
                     logger.info('[{}] - APP NAV: {}'.format(sender_id, app_nav))
                     asyncio.create_task(self.send_app_nav_async(sender_id,app_nav))
-                    APP_NAV.labels(message._metadata['template_name'], 'no_match').inc()
+                    APP_NAV.labels(message._metadata['template_name'], 'no_match', transcriber ).inc()
                     
                 elif message.intent['confidence'] > message._metadata['nlu_threshold']:
                     app_nav = {
-                    'key': '{}_nlu_match'.format(message._metadata['template_name'] ),
+                    'key': '{}_{}_nlu_match'.format(transcriber, message._metadata['template_name'] ),
                     'value': message.intent['name']
                     }
                     logger.info('[{}] - APP NAV: {}'.format(sender_id, app_nav))
                     asyncio.create_task(self.send_app_nav_async(sender_id,app_nav))
-                    APP_NAV.labels(message._metadata['template_name'], 'match').inc()
+                    APP_NAV.labels(message._metadata['template_name'], 'match', transcriber ).inc()
                 else:
                     logger.debug("[{}] - APP NAV: Error logging app_nav: {}".format(sender_id, message))
 
@@ -954,12 +955,12 @@ class MessageProcessor:
             e.timestamp = time.time()
             tracker.update(e, self.domain)
 
-    def _get_tracker(self, sender_id: Text) -> Optional[DialogueStateTracker]:
+    async def _get_tracker(self, sender_id: Text) -> Optional[DialogueStateTracker]:
         sender_id = sender_id or UserMessage.DEFAULT_SENDER_ID
-        return self.tracker_store.get_or_create_tracker(sender_id)
+        return await self.tracker_store.get_or_create_tracker(sender_id)
 
-    def _save_tracker(self, tracker: DialogueStateTracker) -> None:
-        self.tracker_store.save(tracker)
+    async def _save_tracker(self, tracker: DialogueStateTracker) -> None:
+        await self.tracker_store.save(tracker)
 
     def _prob_array_for_action(
             self, action_name: Text
