@@ -198,8 +198,9 @@ def serve_application(
 
     # noinspection PyUnresolvedReferences
     async def clear_model_files(_app: Sanic, _loop: Text) -> None:
-        if app.agent.model_directory:
-            shutil.rmtree(_app.agent.model_directory)
+        for i, agent_ref in enumerate(app.agent):
+            if agent_ref.model_directory:
+                shutil.rmtree(_app.agent[i].model_directory)
 
     async def close_session(app: Sanic, _loop: Text) -> None:
         """Clean up active user sessions before shutting down server"""
@@ -216,8 +217,8 @@ def serve_application(
             if input_channel.is_socketio_channel():
                 await input_channel.disconnect_session()
 
-        if app.agent.tracker_store.event_broker:
-            app.agent.tracker_store.event_broker.flush()
+        if app.agent[0].tracker_store.event_broker:
+            await app.agent[0].tracker_store.event_broker.flush()
 
     app.register_listener(clear_model_files, "after_server_stop")
     app.register_listener(close_session, "before_server_stop")
