@@ -151,7 +151,7 @@ class TrackerStore:
         else:
             return InMemoryTrackerStore(domain)
 
-    def get_or_create_tracker(
+    async def get_or_create_tracker(
             self, sender_id: Text, max_event_history: Optional[int] = None
     ) -> "DialogueStateTracker":
         """Returns tracker or creates one if the retrieval returns None"""
@@ -159,7 +159,7 @@ class TrackerStore:
         if max_event_history:
             self.max_event_history = max_event_history
         if tracker is None:
-            tracker = self.create_tracker(sender_id)
+            tracker = await self.create_tracker(sender_id)
         return tracker
 
     def init_tracker(self, sender_id: Text) -> "DialogueStateTracker":
@@ -170,7 +170,7 @@ class TrackerStore:
             max_event_history=self.max_event_history,
         )
 
-    def create_tracker(
+    async def create_tracker(
             self, sender_id: Text, append_action_listen: bool = True
     ) -> DialogueStateTracker:
         """Creates a new tracker for the sender_id. The tracker is initially listening."""
@@ -178,7 +178,7 @@ class TrackerStore:
         if tracker:
             if append_action_listen:
                 tracker.update(ActionExecuted(ACTION_LISTEN_NAME))
-            self.save(tracker)
+            await self.save(tracker)
         return tracker
 
     def save(self, tracker, timeout=None, stream_only=False):
@@ -188,19 +188,19 @@ class TrackerStore:
         """Retrieve method that will be overriden by specific tracker"""
         raise NotImplementedError()
 
-    def _stream_steps(self, tracker: DialogueStateTracker) -> None:
+    async def _stream_steps(self, tracker: DialogueStateTracker) -> None:
         """Stream steps slot event to a message broker"""
         body = {"sender_id": tracker.sender_id}
         slot_evt = SlotSet('steps', tracker.total_steps)
         body.update(slot_evt.as_dict())
-        self.event_broker.publish(body)
+        await self.event_broker.publish(body)
 
-    def _stream_errors(self, tracker: DialogueStateTracker) -> None:
+    async def _stream_errors(self, tracker: DialogueStateTracker) -> None:
         """Stream total_errors slot event to a message broker"""
         body = {"sender_id": tracker.sender_id}
         slot_evt = SlotSet('total_errors', tracker.total_errors)
         body.update(slot_evt.as_dict())
-        self.event_broker.publish(body)
+        await self.event_broker.publish(body)
 
     @staticmethod
     def is_form_error(tracker: DialogueStateTracker, evt_dict: dict):
@@ -216,7 +216,7 @@ class TrackerStore:
         return evt_dict.get("event") == "action" and (
                 evt_dict.get("name") in ["action_handle_error", DEFAULT_FALLBACK_ACTION])
 
-    def stream_events(self, tracker: DialogueStateTracker) -> None:
+    async def stream_events(self, tracker: DialogueStateTracker) -> None:
         """Streams events to a message broker"""
         offset = self.number_of_existing_events(tracker.sender_id)
         evts = tracker.events
@@ -257,11 +257,15 @@ class TrackerStore:
                     body["metadata"]["prediction_error"] = True
                     prediction_error = False
             tracker.add_conversation_steps(evt)
-            self.event_broker.publish(body)
+            # This function is shared by other non-async producers, below condition limits async use to AIOKafka.
+            if type(self.event_broker).__name__ == "AIOKafkaMiddleware":
+                await self.event_broker.publish(body)
+            else:
+                self.event_broker.publish(body)
 
         if tracker.conversation_ended():
-            self._stream_steps(tracker)
-            self._stream_errors(tracker)
+            await self._stream_steps(tracker)
+            await self._stream_errors(tracker)
         duration = time.perf_counter() - start
         OUTGOING_REQUEST_LATENCY_SEC.labels('kafka_stream', "NA", "NA").observe(duration)
 
@@ -343,9 +347,9 @@ class InMemoryTrackerStore(TrackerStore):
         self.store = {}
         super().__init__(domain, event_broker)
 
-    def save(self, tracker: DialogueStateTracker, timeout=None, stream_only=False) -> None:
+    async def save(self, tracker: DialogueStateTracker, timeout=None, stream_only=False) -> None:
         if self.event_broker:
-            self.stream_events(tracker)
+            await self.stream_events(tracker)
         serialised = InMemoryTrackerStore.serialise_tracker(tracker)
         self.store[tracker.sender_id] = serialised
 
@@ -392,10 +396,10 @@ class RedisTrackerStore(TrackerStore):
         self.record_exp = record_exp
         super().__init__(domain, event_broker)
 
-    def save(self, tracker: DialogueStateTracker, timeout=None, stream_only=False):
+    async def save(self, tracker: DialogueStateTracker, timeout=None, stream_only=False):
         """Saves the current conversation state"""
         if self.event_broker:
-            self.stream_events(tracker)
+            await self.stream_events(tracker)
 
         if stream_only:
             return
@@ -476,10 +480,10 @@ class DynamoTrackerStore(TrackerStore):
             table.meta.client.get_waiter("table_exists").wait(TableName=table_name)
         return dynamo.Table(table_name)
 
-    def save(self, tracker, timeout=None, stream_only=False):
+    async def save(self, tracker, timeout=None, stream_only=False):
         """Saves the current conversation state"""
         if self.event_broker:
-            self.stream_events(tracker)
+            await self.stream_events(tracker)
         self.db.put_item(Item=self.serialise_tracker(tracker))
 
     def serialise_tracker(self, tracker: "DialogueStateTracker") -> Dict:
@@ -637,9 +641,9 @@ class RedisClusterTrackerStore(TrackerStore):
 
         return res
 
-    def save(self, tracker: DialogueStateTracker, timeout=None, stream_only=False):
+    async def save(self, tracker: DialogueStateTracker, timeout=None, stream_only=False):
         if self.event_broker:
-            self.stream_events(tracker)
+            await self.stream_events(tracker)
 
         if stream_only:
             return
@@ -753,10 +757,10 @@ class MongoTrackerStore(TrackerStore):
         """Create an index on the sender_id"""
         self.conversations.create_index("sender_id")
 
-    def save(self, tracker, timeout=None, stream_only=False):
+    async def save(self, tracker, timeout=None, stream_only=False):
         """Saves the current conversation state"""
         if self.event_broker:
-            self.stream_events(tracker)
+            await self.stream_events(tracker)
 
         state = tracker.current_state(EventVerbosity.ALL)
 
@@ -1130,11 +1134,11 @@ class SQLTrackerStore(TrackerStore):
                 )
                 return None
 
-    def save(self, tracker: DialogueStateTracker, timeout=None, stream_only=False) -> None:
+    async def save(self, tracker: DialogueStateTracker, timeout=None, stream_only=False) -> None:
         """Update database with events from the current conversation. (Using sqlalchemy core instead of ORM.)"""
 
         if self.event_broker:
-            self.stream_events(tracker)
+            await self.stream_events(tracker)
 
         with self.engine.connect().execution_options(autocommit=True) as connection:
             # only store recent events
@@ -1266,12 +1270,12 @@ class FailSafeTrackerStore(TrackerStore):
             self.on_tracker_store_error(e)
             return []
 
-    def save(self, tracker: DialogueStateTracker, timeout=None, stream_only=False) -> None:
+    async def save(self, tracker: DialogueStateTracker, timeout=None, stream_only=False) -> None:
         try:
-            self._tracker_store.save(tracker, stream_only=stream_only)
+            await self._tracker_store.save(tracker, stream_only=stream_only)
         except Exception as e:
             self.on_tracker_store_error(e)
-            self.fallback_tracker_store.save(tracker)
+            await self.fallback_tracker_store.save(tracker)
 
     async def is_healthy(self):
         return await self._tracker_store.is_healthy()
