@@ -8,7 +8,7 @@ from rasa.nlu.emulators.no_emulator import NoEmulator
 class DialogflowEmulator(NoEmulator):
     def __init__(self) -> None:
 
-        super(DialogflowEmulator, self).__init__()
+        super().__init__()
         self.name = "api"
 
     def normalise_response_json(self, data: Dict[Text, Any]) -> Dict[Text, Any]:
@@ -16,8 +16,7 @@ class DialogflowEmulator(NoEmulator):
 
         # populate entities dict
         entities = {
-            entity_type: []
-            for entity_type in set([x["entity"] for x in data["entities"]])
+            entity_type: [] for entity_type in {x["entity"] for x in data["entities"]}
         }
 
         for entity in data["entities"]:
