@@ -10,6 +10,7 @@ import requests
 from typing import Any, List, Optional, Text, Dict
 
 from metrics.constants import OUTGOING_REQUEST_LATENCY_SEC
+from rasa.constants import ENV_RASA_DUCKLING_HTTP_URL
 from rasa.nlu.config import RasaNLUModelConfig
 from rasa.nlu.extractors import EntityExtractor
 from rasa.nlu.model import Metadata
@@ -100,8 +101,8 @@ class DucklingHTTPExtractor(EntityExtractor):
 
     def _url(self):
         """Return url of the duckling service. Environment var will override."""
-        if os.environ.get("RASA_DUCKLING_HTTP_URL"):
-            return os.environ["RASA_DUCKLING_HTTP_URL"]
+        if ENV_RASA_DUCKLING_HTTP_URL:
+            return ENV_RASA_DUCKLING_HTTP_URL
 
         return self.component_config.get("url")
 
