@@ -10,12 +10,26 @@ from rasa.nlu.training_data import Message, TrainingData
 if typing.TYPE_CHECKING:
     import mitie
 
+from rasa.nlu.constants import (
+    MESSAGE_RESPONSE_ATTRIBUTE,
+    MESSAGE_INTENT_ATTRIBUTE,
+    MESSAGE_TEXT_ATTRIBUTE,
+    MESSAGE_TOKENS_NAMES,
+    MESSAGE_ATTRIBUTES,
+    MESSAGE_SPACY_FEATURES_NAMES,
+    MESSAGE_VECTOR_FEATURE_NAMES,
+)
+
 
 class MitieFeaturizer(Featurizer):
 
-    provides = ["text_features"]
+    provides = [
+        MESSAGE_VECTOR_FEATURE_NAMES[attribute] for attribute in MESSAGE_ATTRIBUTES
+    ]
 
-    requires = ["tokens", "mitie_feature_extractor"]
+    requires = [MESSAGE_TOKENS_NAMES[attribute] for attribute in MESSAGE_ATTRIBUTES] + [
+        "mitie_feature_extractor"
+    ]
 
     @classmethod
     def required_packages(cls) -> List[Text]:
@@ -25,29 +39,44 @@ class MitieFeaturizer(Featurizer):
 
         return feature_extractor.num_dimensions
 
+    def get_tokens_by_attribute(self, example, attribute):
+
+        return example.get(MESSAGE_TOKENS_NAMES[attribute])
+
     def train(
         self, training_data: TrainingData, config: RasaNLUModelConfig, **kwargs: Any
     ) -> None:
 
         mitie_feature_extractor = self._mitie_feature_extractor(**kwargs)
         for example in training_data.intent_examples:
-            features = self.features_for_tokens(
-                example.get("tokens"), mitie_feature_extractor
-            )
-            example.set(
-                "text_features",
-                self._combine_with_existing_text_features(example, features),
-            )
+
+            for attribute in MESSAGE_ATTRIBUTES:
+
+                attribute_tokens = self.get_tokens_by_attribute(example, attribute)
+                if attribute_tokens is not None:
+
+                    features = self.features_for_tokens(
+                        attribute_tokens, mitie_feature_extractor
+                    )
+                    example.set(
+                        MESSAGE_VECTOR_FEATURE_NAMES[attribute],
+                        self._combine_with_existing_features(
+                            example, features, MESSAGE_VECTOR_FEATURE_NAMES[attribute]
+                        ),
+                    )
 
     async def process(self, message: Message, **kwargs: Any) -> None:
 
         mitie_feature_extractor = self._mitie_feature_extractor(**kwargs)
         features = self.features_for_tokens(
-            message.get("tokens"), mitie_feature_extractor
+            message.get(MESSAGE_TOKENS_NAMES[MESSAGE_TEXT_ATTRIBUTE]),
+            mitie_feature_extractor,
         )
         message.set(
-            "text_features",
-            self._combine_with_existing_text_features(message, features),
+            MESSAGE_VECTOR_FEATURE_NAMES[MESSAGE_TEXT_ATTRIBUTE],
+            self._combine_with_existing_features(
+                message, features, MESSAGE_VECTOR_FEATURE_NAMES[MESSAGE_TEXT_ATTRIBUTE]
+            ),
         )
 
     def _mitie_feature_extractor(self, **kwargs):
