@@ -5,6 +5,8 @@ import shutil
 import tarfile
 from typing import List, Optional, Text, Tuple
 
+from rasa.constants import ENV_AWS_ENDPOINT_URL, ENV_AZURE_ACCOUNT_KEY, ENV_AZURE_ACCOUNT_NAME, ENV_AZURE_CONTAINER, ENV_BUCKET_NAME
+
 
 logger = logging.getLogger(__name__)
 
@@ -16,16 +18,16 @@ def get_persistor(name: Text) -> Optional["Persistor"]:
 
     if name == "aws":
         return AWSPersistor(
-            os.environ.get("BUCKET_NAME"), os.environ.get("AWS_ENDPOINT_URL")
+            ENV_BUCKET_NAME, ENV_AWS_ENDPOINT_URL
         )
     if name == "gcs":
-        return GCSPersistor(os.environ.get("BUCKET_NAME"))
+        return GCSPersistor(ENV_BUCKET_NAME)
 
     if name == "azure":
         return AzurePersistor(
-            os.environ.get("AZURE_CONTAINER"),
-            os.environ.get("AZURE_ACCOUNT_NAME"),
-            os.environ.get("AZURE_ACCOUNT_KEY"),
+            ENV_AZURE_CONTAINER,
+            ENV_AZURE_ACCOUNT_NAME,
+            ENV_AZURE_ACCOUNT_KEY,
         )
 
     return None
