@@ -107,9 +107,9 @@ def ensure_loaded_agent(app: Sanic, require_core_is_ready=False):
         def decorated(*args, **kwargs):
             # noinspection PyUnresolvedReferences
             if not app.agent or not (
-                app.agent.is_core_ready()
+                app.agent[0].is_core_ready()
                 if require_core_is_ready
-                else app.agent.is_ready()
+                else app.agent[0].is_ready()
             ):
                 raise ErrorResponse(
                     409,
@@ -224,8 +224,8 @@ def event_verbosity_parameter(
         )
 
 
-def get_tracker(agent: "Agent", conversation_id: Text) -> DialogueStateTracker:
-    tracker = agent.tracker_store.get_or_create_tracker(conversation_id)
+async def get_tracker(agent: "Agent", conversation_id: Text) -> DialogueStateTracker:
+    tracker = await agent[0].tracker_store.get_or_create_tracker(conversation_id)
     if not tracker:
         raise ErrorResponse(
             409,
@@ -463,7 +463,7 @@ def create_app(
         """Check if the server is running and responds with the version."""
         try:
             if endpoints.tracker_store:
-                resp = await app.agent.tracker_store.is_healthy()
+                resp = await app.agent[0].tracker_store.is_healthy()
 
                 if not resp:
                     logger.error({"event": "HEALTH_CHECK", "message": "Tracker store is unhealthy."})
@@ -485,11 +485,11 @@ def create_app(
             if ENV_READY_CHECK_OFF:
                 return response.json({"status": "ok"})
             if endpoints.tracker_store:
-                resp = await app.agent.tracker_store.is_healthy()
+                resp = await app.agent[0].tracker_store.is_healthy()
                 if not resp:
                     logger.error({"event": "HEALTH_CHECK", "message": "Tracker store is unhealthy."})
                     raise ErrorResponse(500, "ServerError", "Tracker store is unhealthy.")
-            if not app.agent.is_ready():
+            if not app.agent[0].is_ready():
                 raise ErrorResponse(500, "AgentError", "Agent is not ready yet.")
             return response.json({"status": "ok"})
         except Exception as err:
@@ -499,7 +499,7 @@ def create_app(
     @app.get("/model/version/<fileName>")
     async def model_version(request: Request, fileName):
         try:
-            with open('data/' + fileName) as f:
+            with open('data_english/' + fileName) as f:
                 searchTitle = re.search(r'<!--- FileName:\s+(.*?)\s+--->', f.readline())
                 searchDate = re.search(r'<!--- ExportDate:\s+(.*?)\s+--->', f.readline())
                 if (searchTitle and searchTitle.group(1)):
@@ -517,7 +517,7 @@ def create_app(
     @app.route('/model/download/<fileName>')
     async def download_file(request: Request, fileName):
         try:
-            return await response.file("data/" + fileName, status=200)
+            return await response.file("data_english/" + fileName, status=200)
         except Exception as err:
             logger.error({"event": "MODEL_VERSION", "message": f'failed to retrieve nlu file. {err}'}, exc_info=True)
             raise ErrorResponse(500, "ServerError", message=f'failed to retrieve nlu file {fileName}', details=str(err))
@@ -537,9 +537,9 @@ def create_app(
 
         return response.json(
             {
-                "model_file": app.agent.path_to_model_archive
-                or app.agent.model_directory,
-                "fingerprint": model.fingerprint_from_path(app.agent.model_directory),
+                "model_file": app.agent[0].path_to_model_archive
+                or app.agent[0].model_directory,
+                "fingerprint": model.fingerprint_from_path(app.agent[0].model_directory),
                 "num_active_training_jobs": app.active_training_processes.value,
             }
         )
@@ -553,7 +553,7 @@ def create_app(
         verbosity = event_verbosity_parameter(request, EventVerbosity.AFTER_RESTART)
         until_time = rasa.utils.endpoints.float_arg(request, "until")
 
-        tracker = get_tracker(app.agent, conversation_id)
+        tracker = await get_tracker(app.agent, conversation_id)
 
         try:
             if until_time is not None:
@@ -573,7 +573,7 @@ def create_app(
     async def retrieve_tracker(request: Request, conversation_id: Text):
         """Check if tracker exists in the tracker store with the given conversation_id"""
         try:
-            tracker = app.agent.tracker_store.retrieve(conversation_id)
+            tracker = app.agent[0].tracker_store.retrieve(conversation_id)
             if tracker:
                 return response.json({"sender_id": conversation_id, "exists": True})
             else:
@@ -622,11 +622,11 @@ def create_app(
 
         try:
             stream_only = False
-            async with app.agent.lock_store.lock(conversation_id):
-                tracker = get_tracker(app.agent, conversation_id)
+            async with app.agent[0].lock_store.lock(conversation_id):
+                tracker = await get_tracker(app.agent, conversation_id)
                 for event in events:
                     if isinstance(event, UserUttered) and event.intent.get("name") == USER_INTENT_DISCONNECT and not tracker.conversation_ended():
-                        tracker.update(event, app.agent.domain)
+                        tracker.update(event, app.agent[0].domain)
                         if tracker.from_voice_channel():
                             outcome = 'HANGUP'
                         else:
@@ -636,9 +636,9 @@ def create_app(
                         tracker.update(SlotSet("system_event", value=val, timestamp=event.timestamp + 2))
                         stream_only = True
                     else:
-                        tracker.update(event, app.agent.domain)
+                        tracker.update(event, app.agent[0].domain)
 
-                app.agent.tracker_store.save(tracker=tracker, timeout=None, stream_only=stream_only)
+                await app.agent[0].tracker_store.save(tracker=tracker, timeout=None, stream_only=stream_only)
 
             return response.json(tracker.current_state(verbosity))
         except Exception as e:
@@ -661,13 +661,13 @@ def create_app(
         verbosity = event_verbosity_parameter(request, EventVerbosity.AFTER_RESTART)
 
         try:
-            async with app.agent.lock_store.lock(conversation_id):
+            async with app.agent[0].lock_store.lock(conversation_id):
                 tracker = DialogueStateTracker.from_dict(
-                    conversation_id, request.json, app.agent.domain.slots
+                    conversation_id, request.json, app.agent[0].domain.slots
                 )
 
                 # will override an existing tracker with the same id!
-                app.agent.tracker_store.save(tracker)
+                await app.agent[0].tracker_store.save(tracker)
 
             return response.json(tracker.current_state(verbosity))
         except Exception as e:
@@ -721,10 +721,10 @@ def create_app(
         verbosity = event_verbosity_parameter(request, EventVerbosity.AFTER_RESTART)
 
         try:
-            async with app.agent.lock_store.lock(conversation_id):
+            async with app.agent[0].lock_store.lock(conversation_id):
                 tracker = get_tracker(app.agent, conversation_id)
                 output_channel = _get_output_channel(request, tracker)
-                await app.agent.execute_action(
+                await app.agent[0].execute_action(
                     conversation_id,
                     action_to_execute,
                     output_channel,
@@ -738,7 +738,7 @@ def create_app(
                 500, "ConversationError", f"An unexpected error occurred. Error: {e}"
             )
 
-        tracker = get_tracker(app.agent, conversation_id)
+        tracker = await get_tracker(app.agent, conversation_id)
         state = tracker.current_state(verbosity)
 
         response_body = {"tracker": state}
@@ -754,7 +754,7 @@ def create_app(
     async def predict(request: Request, conversation_id: Text):
         try:
             # Fetches the appropriate bot response in a json format
-            responses = await app.agent.predict_next(conversation_id)
+            responses = await app.agent[0].predict_next(conversation_id)
             responses["scores"] = sorted(
                 responses["scores"], key=lambda k: (-k["score"], k["action"])
             )
@@ -796,8 +796,8 @@ def create_app(
         user_message = UserMessage(message, None, conversation_id, parse_data)
 
         try:
-            async with app.agent.lock_store.lock(conversation_id):
-                tracker = await app.agent.log_message(user_message)
+            async with app.agent[0].lock_store.lock(conversation_id):
+                tracker = await app.agent[0].log_message(user_message)
             return response.json(tracker.current_state(verbosity))
         except Exception as e:
             logger.debug(traceback.format_exc())
@@ -946,20 +946,20 @@ def create_app(
 
         model_path = request.args.get("model", None)
         if model_path:
-            model_server = app.agent.model_server
+            model_server = app.agent[0].model_server
             if model_server is not None:
                 model_server.url = model_path
             eval_agent = await _load_agent(
-                model_path, model_server, app.agent.remote_storage
+                model_path, model_server, app.agent[0].remote_storage
             )
 
         nlu_data = rasa.utils.io.create_temporary_file(request.body, mode="w+b")
         data_path = os.path.abspath(nlu_data)
 
-        if not os.path.exists(eval_agent.model_directory):
+        if not os.path.exists(eval_agent[0].model_directory):
             raise ErrorResponse(409, "Conflict", "Loaded model file not found.")
 
-        model_directory = eval_agent.model_directory
+        model_directory = eval_agent[0].model_directory
         _, nlu_model = model.get_model_subdirectories(model_directory)
 
         try:
@@ -989,7 +989,7 @@ def create_app(
         request_params = request.json
         try:
             tracker = DialogueStateTracker.from_dict(
-                sender_id, request_params, app.agent.domain.slots
+                sender_id, request_params, app.agent[0].domain.slots
             )
         except Exception as e:
             logger.debug(traceback.format_exc())
@@ -1001,14 +1001,14 @@ def create_app(
             )
 
         try:
-            policy_ensemble = app.agent.policy_ensemble
+            policy_ensemble = app.agent[0].policy_ensemble
             probabilities, policy = policy_ensemble.probabilities_using_best_policy(
-                tracker, app.agent.domain
+                tracker, app.agent[0].domain
             )
 
             scores = [
                 {"action": a, "score": p}
-                for a, p in zip(app.agent.domain.action_names, probabilities)
+                for a, p in zip(app.agent[0].domain.action_names, probabilities)
             ]
 
             return response.json(
@@ -1039,7 +1039,7 @@ def create_app(
         try:
             data = emulator.normalise_request_json(request.json)
             try:
-                parsed_data = await app.agent.parse_message_using_nlu_interpreter(
+                parsed_data = await app.agent[0].parse_message_using_nlu_interpreter(
                     data.get("text")
                 )
             except Exception as e:
@@ -1051,7 +1051,7 @@ def create_app(
 
             # Publish the payload through the event broker.
             try:
-                _broker = app.agent.tracker_store.event_broker
+                _broker = app.agent[0].tracker_store.event_broker
                 if _broker:
                     event = {
                         'event': 'nlu',
@@ -1096,7 +1096,7 @@ def create_app(
             try:
                 predList = []
                 for phrase in phrase_list:
-                    parsed_data = await app.agent.parse_message_using_nlu_interpreter(
+                    parsed_data = await app.agent[0].parse_message_using_nlu_interpreter(
                         phrase['text']
                     )
                     predList.append(parsed_data)
@@ -1141,7 +1141,7 @@ def create_app(
                 )
 
         app.agent = await _load_agent(
-            model_path, model_server, remote_storage, endpoints, app.agent.lock_store
+            model_path, model_server, remote_storage, endpoints, app.agent[0].lock_store
         )
 
         logger.debug(f"Successfully loaded model '{model_path}'.")
@@ -1150,9 +1150,9 @@ def create_app(
     @app.delete("/model")
     @requires_auth(app, auth_token)
     async def unload_model(request: Request):
-        model_file = app.agent.model_directory
+        model_file = app.agent[0].model_directory
 
-        app.agent = Agent(lock_store=app.agent.lock_store)
+        app.agent = Agent(lock_store=app.agent[0].lock_store)
 
         logger.debug(f"Successfully unloaded model '{model_file}'.")
         return response.json(None, status=204)
@@ -1165,10 +1165,10 @@ def create_app(
 
         accepts = request.headers.get("Accept", default="application/json")
         if accepts.endswith("json"):
-            domain = app.agent.domain.as_dict()
+            domain = app.agent[0].domain.as_dict()
             return response.json(domain)
         elif accepts.endswith("yml") or accepts.endswith("yaml"):
-            domain_yaml = app.agent.domain.as_yaml()
+            domain_yaml = app.agent[0].domain.as_yaml()
             return response.text(
                 domain_yaml, status=200, content_type="application/x-yml"
             )
@@ -1217,7 +1217,7 @@ def create_app(
                 return response.json(None, 200)
             if tracker.get_slot("handoff_active"):
                 output_channel = _get_output_channel_without_request(app, tracker)
-                await app.agent.execute_action(
+                await app.agent[0].execute_action(
                     conversation_id, action_to_execute, output_channel, policy, confidence
                 )
         except Exception as e:
@@ -1230,7 +1230,7 @@ def create_app(
 
         tracker = obtain_tracker_store(app.agent, conversation_id)
         if tracker.latest_action_name == "action_human_end_conversation":
-            await app.agent.execute_action(
+            await app.agent[0].execute_action(
                 conversation_id, "action_listen", output_channel, policy, confidence
             )
         state = tracker.current_state(verbosity)
