@@ -1,8 +1,10 @@
 import os
 import shutil
+from typing import Callable
+from _pytest.pytester import RunResult
 
 
-def test_run_does_not_start(run_in_default_project):
+def test_run_does_not_start(run_in_default_project: Callable[..., RunResult]):
     os.remove("domain.yml")
     shutil.rmtree("models")
 
@@ -12,13 +14,16 @@ def test_run_does_not_start(run_in_default_project):
     assert "No model found." in output.outlines[0]
 
 
-def test_run_help(run):
+def test_run_help(run: Callable[..., RunResult]):
     output = run("run", "--help")
 
     help_text = """usage: rasa run [-h] [-v] [-vv] [--quiet] [-m MODEL] [--log-file LOG_FILE]
                 [--endpoints ENDPOINTS] [-p PORT] [-t AUTH_TOKEN]
                 [--cors [CORS [CORS ...]]] [--enable-api]
-                [--remote-storage REMOTE_STORAGE] [--credentials CREDENTIALS]
+                [--remote-storage REMOTE_STORAGE]
+                [--ssl-certificate SSL_CERTIFICATE]
+                [--ssl-keyfile SSL_KEYFILE] [--ssl-ca-file SSL_CA_FILE]
+                [--ssl-password SSL_PASSWORD] [--credentials CREDENTIALS]
                 [--connector CONNECTOR] [--jwt-secret JWT_SECRET]
                 [--jwt-method JWT_METHOD]
                 {actions} ... [model-as-positional-argument]"""
@@ -29,7 +34,7 @@ def test_run_help(run):
         assert output.outlines[i] == line
 
 
-def test_run_action_help(run):
+def test_run_action_help(run: Callable[..., RunResult]):
     output = run("run", "actions", "--help")
 
     help_text = """usage: rasa run actions [-h] [-v] [-vv] [--quiet] [-p PORT]
