@@ -3,9 +3,12 @@ import shutil
 import tempfile
 
 import pytest
+from typing import Callable
+from _pytest.pytester import RunResult
 
 from rasa import model
-
+from rasa.nlu.model import Metadata
+from rasa.nlu.training_data import training_data
 from rasa.cli.train import _get_valid_config
 from rasa.constants import (
     CONFIG_MANDATORY_KEYS_CORE,
@@ -15,7 +18,7 @@ from rasa.constants import (
 import rasa.utils.io as io_utils
 
 
-def test_train(run_in_default_project):
+def test_train(run_in_default_project: Callable[..., RunResult]):
     temp_dir = os.getcwd()
 
     run_in_default_project(
@@ -36,9 +39,47 @@ def test_train(run_in_default_project):
     files = io_utils.list_files(os.path.join(temp_dir, "train_models"))
     assert len(files) == 1
     assert os.path.basename(files[0]) == "test-model.tar.gz"
+    model_dir = model.get_model("train_models")
+    assert model_dir is not None
+    metadata = Metadata.load(os.path.join(model_dir, "nlu"))
+    assert metadata.get("training_data") is None
+    assert not os.path.exists(
+        os.path.join(model_dir, "nlu", training_data.DEFAULT_TRAINING_DATA_OUTPUT_PATH)
+    )
 
 
-def test_train_core_compare(run_in_default_project):
+def test_train_persist_nlu_data(run_in_default_project: Callable[..., RunResult]):
+    temp_dir = os.getcwd()
+
+    run_in_default_project(
+        "train",
+        "-c",
+        "config.yml",
+        "-d",
+        "domain.yml",
+        "--data",
+        "data",
+        "--out",
+        "train_models",
+        "--fixed-model-name",
+        "test-model",
+        "--persist-nlu-data",
+    )
+
+    assert os.path.exists(os.path.join(temp_dir, "train_models"))
+    files = io_utils.list_files(os.path.join(temp_dir, "train_models"))
+    assert len(files) == 1
+    assert os.path.basename(files[0]) == "test-model.tar.gz"
+    model_dir = model.get_model("train_models")
+    assert model_dir is not None
+    metadata = Metadata.load(os.path.join(model_dir, "nlu"))
+    assert metadata.get("training_data") is not None
+    assert os.path.exists(
+        os.path.join(model_dir, "nlu", training_data.DEFAULT_TRAINING_DATA_OUTPUT_PATH)
+    )
+
+
+def test_train_core_compare(run_in_default_project: Callable[..., RunResult]):
     temp_dir = os.getcwd()
 
     io_utils.write_yaml_file(
@@ -90,7 +131,9 @@ def test_train_core_compare(run_in_default_project):
     assert model_files[0].endswith("tar.gz")
 
 
-def test_train_no_domain_exists(run_in_default_project):
+def test_train_no_domain_exists(
+    run_in_default_project: Callable[..., RunResult]
+) -> None:
 
     os.remove("domain.yml")
     run_in_default_project(
@@ -116,7 +159,9 @@ def test_train_no_domain_exists(run_in_default_project):
     assert os.path.exists(metadata_path)
 
 
-def test_train_skip_on_model_not_changed(run_in_default_project):
+def test_train_skip_on_model_not_changed(
+    run_in_default_project: Callable[..., RunResult]
+):
     temp_dir = os.getcwd()
 
     assert os.path.exists(os.path.join(temp_dir, "models"))
@@ -176,7 +221,7 @@ def test_train_with_only_core_data(run_in_default_project):
     assert os.path.basename(files[0]) == "test-model.tar.gz"
 
 
-def test_train_core(run_in_default_project):
+def test_train_core(run_in_default_project: Callable[..., RunResult]):
     run_in_default_project(
         "train",
         "core",
@@ -196,7 +241,7 @@ def test_train_core(run_in_default_project):
     assert os.path.isfile("train_rasa_models/rasa-model.tar.gz")
 
 
-def test_train_core_no_domain_exists(run_in_default_project):
+def test_train_core_no_domain_exists(run_in_default_project: Callable[..., RunResult]):
 
     os.remove("domain.yml")
     run_in_default_project(
@@ -218,30 +263,7 @@ def test_train_core_no_domain_exists(run_in_default_project):
     assert not os.path.isfile("train_rasa_models_no_domain/rasa-model.tar.gz")
 
 
-def count_rasa_temp_files():
-    count = 0
-    for entry in os.scandir(tempfile.gettempdir()):
-        if not entry.is_dir():
-            continue
-
-        try:
-            for f in os.listdir(entry.path):
-                if f.endswith("_nlu.md") or f.endswith("_stories.md"):
-                    count += 1
-        except PermissionError:
-            # Ignore permission errors
-            pass
-
-    return count
-
-
-def test_train_core_temp_files(run_in_default_project):
-    count = count_rasa_temp_files()
-    run_in_default_project("train", "core")
-    assert count == count_rasa_temp_files()
-
-
-def test_train_nlu(run_in_default_project):
+def test_train_nlu(run_in_default_project: Callable[..., RunResult]):
     run_in_default_project(
         "train",
         "nlu",
@@ -257,12 +279,41 @@ def test_train_nlu(run_in_default_project):
     files = io_utils.list_files("train_models")
     assert len(files) == 1
     assert os.path.basename(files[0]).startswith("nlu-")
+    model_dir = model.get_model("train_models")
+    assert model_dir is not None
+    metadata = Metadata.load(os.path.join(model_dir, "nlu"))
+    assert metadata.get("training_data") is None
+    assert not os.path.exists(
+        os.path.join(model_dir, "nlu", training_data.DEFAULT_TRAINING_DATA_OUTPUT_PATH)
+    )
 
 
-def test_train_nlu_temp_files(run_in_default_project):
-    count = count_rasa_temp_files()
-    run_in_default_project("train", "nlu")
-    assert count == count_rasa_temp_files()
+def test_train_nlu_persist_nlu_data(
+    run_in_default_project: Callable[..., RunResult]
+) -> None:
+    run_in_default_project(
+        "train",
+        "nlu",
+        "-c",
+        "config.yml",
+        "--nlu",
+        "data/nlu.md",
+        "--out",
+        "train_models",
+        "--persist-nlu-data",
+    )
+
+    assert os.path.exists("train_models")
+    files = io_utils.list_files("train_models")
+    assert len(files) == 1
+    assert os.path.basename(files[0]).startswith("nlu-")
+    model_dir = model.get_model("train_models")
+    assert model_dir is not None
+    metadata = Metadata.load(os.path.join(model_dir, "nlu"))
+    assert metadata.get("training_data") is not None
+    assert os.path.exists(
+        os.path.join(model_dir, "nlu", training_data.DEFAULT_TRAINING_DATA_OUTPUT_PATH)
+    )
 
 
 def test_train_help(run):
@@ -272,7 +323,7 @@ def test_train_help(run):
                   [-c CONFIG] [-d DOMAIN] [--out OUT]
                   [--augmentation AUGMENTATION] [--debug-plots]
                   [--dump-stories] [--fixed-model-name FIXED_MODEL_NAME]
-                  [--force]
+                  [--persist-nlu-data] [--force]
                   {core,nlu} ..."""
 
     lines = help_text.split("\n")
@@ -281,11 +332,12 @@ def test_train_help(run):
         assert output.outlines[i] == line
 
 
-def test_train_nlu_help(run):
+def test_train_nlu_help(run: Callable[..., RunResult]):
     output = run("train", "nlu", "--help")
 
     help_text = """usage: rasa train nlu [-h] [-v] [-vv] [--quiet] [-c CONFIG] [--out OUT]
-                      [-u NLU] [--fixed-model-name FIXED_MODEL_NAME]"""
+                      [-u NLU] [--fixed-model-name FIXED_MODEL_NAME]
+                      [--persist-nlu-data]"""
 
     lines = help_text.split("\n")
 
@@ -293,7 +345,7 @@ def test_train_nlu_help(run):
         assert output.outlines[i] == line
 
 
-def test_train_core_help(run):
+def test_train_core_help(run: Callable[..., RunResult]):
     output = run("train", "core", "--help")
 
     help_text = """usage: rasa train core [-h] [-v] [-vv] [--quiet] [-s STORIES] [-d DOMAIN]
