@@ -1,5 +1,4 @@
 import asyncio
-import logging
 import os
 from typing import Text
 
@@ -7,7 +6,6 @@ import matplotlib
 import pytest
 
 import rasa.utils.io
-from rasa.core import train
 from rasa.core.agent import Agent
 from rasa.core.channels.channel import CollectingOutputChannel
 from rasa.core.domain import Domain
@@ -25,7 +23,6 @@ from rasa.core.tracker_store import InMemoryTrackerStore
 from rasa.core.trackers import DialogueStateTracker
 from rasa.train import train_async
 
-matplotlib.use("Agg")
 
 DEFAULT_DOMAIN_PATH_WITH_SLOTS = "data/test_domains/default_with_slots.yml"
 
@@ -74,7 +71,7 @@ class ExamplePolicy(Policy):
         pass
 
 
-@pytest.fixture
+@pytest.fixture(scope="session")
 def loop():
     loop = asyncio.new_event_loop()
     asyncio.set_event_loop(loop)
@@ -109,7 +106,7 @@ def default_domain():
 
 
 @pytest.fixture(scope="session")
-async def default_agent(default_domain):
+async def default_agent(default_domain) -> Agent:
     agent = Agent(
         default_domain,
         policies=[MemoizationPolicy()],
@@ -168,10 +165,14 @@ def moodbot_metadata(unpacked_trained_moodbot_path):
 
 @pytest.fixture()
 async def trained_stack_model(
-    default_domain_path, default_stack_config, default_nlu_data, default_stories_file
+    trained_async,
+    default_domain_path,
+    default_stack_config,
+    default_nlu_data,
+    default_stories_file,
 ):
 
-    trained_stack_model_path = await train_async(
+    trained_stack_model_path = await trained_async(
         domain=default_domain_path,
         config=default_stack_config,
         training_files=[default_nlu_data, default_stories_file],
@@ -216,7 +217,7 @@ def project() -> Text:
     return directory
 
 
-def train_model(project: Text, filename: Text = "test.tar.gz"):
+def train_model(loop, project: Text, filename: Text = "models_english/test.tar.gz"):
     from rasa.constants import (
         DEFAULT_CONFIG_PATH,
         DEFAULT_DATA_PATH,
@@ -230,24 +231,34 @@ def train_model(project: Text, filename: Text = "test.tar.gz"):
     config = os.path.join(project, DEFAULT_CONFIG_PATH)
     training_files = os.path.join(project, DEFAULT_DATA_PATH)
 
-    rasa.train(domain, config, training_files, output)
+    rasa.train(domain, config, training_files, output, loop=loop)
 
     return output
 
 
 @pytest.fixture(scope="session")
-def trained_model(project) -> Text:
-    return train_model(project)
+def trained_model(loop, project) -> Text:
+    return train_model(loop, project)
 
 
 @pytest.fixture
-async def restaurantbot(tmpdir_factory) -> Text:
-    model_path = tmpdir_factory.mktemp("model").strpath
+async def restaurantbot(trained_async) -> Text:
     restaurant_domain = os.path.join(RESTAURANTBOT_PATH, "domain.yml")
     restaurant_config = os.path.join(RESTAURANTBOT_PATH, "config.yml")
     restaurant_data = os.path.join(RESTAURANTBOT_PATH, "data/")
 
-    agent = await train_async(
-        restaurant_domain, restaurant_config, restaurant_data, model_path
+    return await trained_async(restaurant_domain, restaurant_config, restaurant_data)
+
+
+@pytest.fixture
+async def form_bot(trained_async) -> Agent:
+    zipped_model = await trained_async(
+        domain="examples/formbot/domain.yml",
+        config="examples/formbot/config.yml",
+        training_files=[
+            "examples/formbot/data/stories.md",
+            "examples/formbot/data/nlu.md",
+        ],
     )
-    return agent
+
+    return Agent.load_local_model(zipped_model)
