@@ -195,9 +195,12 @@ async def test_wait_time_between_pulls_without_interval(model_server, monkeypatc
 async def test_load_agent(trained_model):
     agent = await load_agent(model_path=trained_model)
 
-    assert agent.tracker_store is not None
-    assert agent.interpreter is not None
-    assert agent.model_directory is not None
+    assert agent[0].tracker_store is not None
+    assert agent[0].interpreter is not None
+    assert agent[0].model_directory is not None
+    assert agent[1].tracker_store is not None
+    assert agent[1].interpreter is not None
+    assert agent[1].model_directory is not None
 
 
 @pytest.mark.parametrize(
@@ -249,17 +252,17 @@ def test_two_stage_fallback_without_deny_suggestion(domain, policy_config):
 
 async def test_agent_update_model_none_domain(trained_model):
     agent = await load_agent(model_path=trained_model)
-    agent.update_model(
-        None, None, agent.fingerprint, agent.interpreter, agent.model_directory
+    agent[0].update_model(
+        None, None, agent[0].fingerprint, agent[0].interpreter, agent[0].model_directory
     )
 
     sender_id = "test_sender_id"
     message = UserMessage("hello", sender_id=sender_id)
-    await agent.handle_message(message)
-    tracker = agent.tracker_store.get_or_create_tracker(sender_id)
+    await agent[0].handle_message(message)
+    tracker = await agent[0].tracker_store.get_or_create_tracker(sender_id)
 
     # UserUttered event was added to tracker, with correct intent data
-    assert tracker.events[1].intent["name"] == "greet"
+    assert tracker.events[1].intent["name"] == "hello"
 
 
 async def test_load_agent_on_not_existing_path():
